==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/CONTRACTCHARGEDEFINITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTCHARGEDEFINITIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTCHARGEDEFINITIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTCHARGEDEFINITIONCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTCHARGEDEFINITIONID_Type", propOrder = {
    "contractchargedefinitioncode"
})
public class CONTRACTCHARGEDEFINITIONID_Type {

    @XmlElement(name = "CONTRACTCHARGEDEFINITIONCODE", required = true)
    protected String contractchargedefinitioncode;

    /**
     * Gets the value of the contractchargedefinitioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTCHARGEDEFINITIONCODE() {
        return contractchargedefinitioncode;
    }

    /**
     * Sets the value of the contractchargedefinitioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTCHARGEDEFINITIONCODE(String value) {
        this.contractchargedefinitioncode = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/CONTRACTCHARGEDEFINITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTCHARGEDEFINITIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTCHARGEDEFINITIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTCHARGEDEFINITIONCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTCHARGEDEFINITIONID_Type", propOrder = {
    "contractchargedefinitioncode"
})
public class CONTRACTCHARGEDEFINITIONID_Type {

    @XmlElement(name = "CONTRACTCHARGEDEFINITIONCODE", required = true)
    protected String contractchargedefinitioncode;

    /**
     * Obtient la valeur de la propriété contractchargedefinitioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTCHARGEDEFINITIONCODE() {
        return contractchargedefinitioncode;
    }

    /**
     * Définit la valeur de la propriété contractchargedefinitioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTCHARGEDEFINITIONCODE(String value) {
        this.contractchargedefinitioncode = value;
    }

}
